Maintenance — MARV Robotics 3.3.5 documentation

# Maintenance

## Cleanup

When searching for tags and other `subset` filters, marv presents lists of existing tags. To present only used items, these lists need to be regularly cleaned-up.

    marv cleanup --unused-tags

When datasets are deleted (via frontend, API, cli) they are only marked as discarded and can be “undiscarded”.

    marv undiscard --help

To actually delete these

    marv cleanup --discarded

Additional cleanup operations will be added in one of the next releases.